@@ -122,7 +122,7 @@ sub _version_or_vendor {
             my $val;
             eval "\$self->_try_$what";
             die $@ if $@;
-        } elsif ($self->jsr77 ) {
+        } elsif ($self->jsr77) {
             $self->{$what} = $self->_server_info_from_jsr77("server" . (uc substr($what,0,1)) . substr($what,1));
             $self->{"original_" . $what} = $self->{$what};
             if ($transform && $self->{$what}) {
@@ -327,12 +327,12 @@ return an arrayref in the form described above.
 
 =item *
 
-A coderef, which is executed when C<JMX::Jmx4Perl->get_attribute()> or
-C<JMX::Jmx4Perl->execute()> is called and which is supossed to do the complete
+A coderef, which is executed when C<JMX::Jmx4Perl-E<gt>get_attribute()> or
+C<JMX::Jmx4Perl-E<gt>execute()> is called and which is supossed to do the complete
 lookup. The first argument to the subroutine is the handler which can be used
 to access the L<JMX::Jmx4Perl> object. The additional argument are either the
-value to set (for C<JMX::Jmx4Perl->set_attribute()> or the operation's
-arguments for C<JMX::Jmx4Perl->execute()>. This is the most flexible way for a
+value to set (for C<JMX::Jmx4Perl-E<gt>set_attribute()> or the operation's
+arguments for C<JMX::Jmx4Perl-E<gt>execute()>. This is the most flexible way for a
 handler to do anything it likes to do when an attribute value is requested or
 an operation is about to be executed. You have to return a
 L<JMX::Jmx4Perl::Response> object.
@@ -471,7 +471,6 @@ sub jvm_info {
 
     # Collect all alias and create a map with values
     my $info_map = $self->_fetch_info(\@info);
-
     # Prepare output
     while (@info) {
         my $titel = shift @info;
@@ -537,8 +536,12 @@ sub _fetch_info {
         }
     }
     my @resps = $jmx4perl->request(@reqs);
+    #print Dumper(\@resps);
     foreach my $resp (@resps) {
-        $info_map->{shift @aliases} = $resp->value;
+        my $alias = shift @aliases;
+        if ($resp->{status} == 200) {
+            $info_map->{$alias} = $resp->{value};
+        }
     }
     return $info_map;
 }
@@ -590,7 +593,6 @@ sub _get_attribute {
     my $response = $jmx4perl->request($request);
     return undef if $response->status == 404;     # Ignore attributes not found
     return $response->value if $response->is_ok;
-    print Dumper($response);
     die "Error fetching attribute ","@_",": ",$response->error_text;
 }
 
